<template>
    <div class="app-container">
        <div style="margin-bottom: 10px">
            <el-button
                type="primary"
                plain
                icon="Plus"
                @click="openDialog('add',{})"
            >新增</el-button>
        </div>
        <!-- 表格数据 -->
        <el-table v-loading="loading" :data="dataList" :border="true">
          <el-table-column label="用户ID" prop="id" align="center"/>
          <el-table-column label="机构名称" prop="agency.name" align="center"/>
          <el-table-column label="信用代码" prop="agency.creditCode" align="center"/>
          <el-table-column label="用户名" prop="username" align="center" />
          <el-table-column label="注册手机号" prop="phone" align="center"/>
          <el-table-column label="注册审批" prop="state" align="center">
            <template #default="scope">
              <el-tag :type=" scope.row.state == 0 ? 'info' : scope.row.state == 1 ? '' : scope.row.state == 2 ?'success': scope.row.state == 3 || scope.row.state == 4 ?'danger':''">
                {{scope.row.state == 0?'暂存':scope.row.state == 1 ? '审核中':scope.row.state == 2 ? '审批通过':scope.row.state == 3? '审批驳回':'已作废' }}
              </el-tag>
            </template>
          </el-table-column>
          <el-table-column label="状态" prop="status" align="center">
            <template #default="scope">
              <el-switch
                  v-if="scope.row.state == 2"
                  v-model="scope.row.status"
                  :active-value="0"
                  :inactive-value="1"
                  inline-prompt
                  active-text="正常"
                  inactive-text="停用"
                  @change="switchStatus($event,scope.row)"
              />
              <span v-else>--</span>
            </template>
          </el-table-column>
          <el-table-column label="操作" align="center" width="250" class-name="small-padding fixed-width" >
              <template #default="scope">
                <el-button link type="primary" @click="openDialog('view',scope.row)">查看</el-button>
                <el-button link type="primary" @click="openDialog('edit',scope.row)">编辑</el-button>
                <el-button link type="danger" @click="handleDelete(scope.row)">删除</el-button>
                <el-button link type="primary" v-if="isSuper && scope.row.state ==1 " @click="openApprove(scope.row)">审批</el-button>
                <el-button link type="primary" @click="openPwd('pwd',scope.row)">修改密码</el-button>
              </template>
          </el-table-column>
        </el-table>

        <pagination
            v-show="total > 0"
            :total="total"
            v-model:page="queryParams.pageNum"
            v-model:limit="queryParams.pageSize"
            @pagination="getList"
        />
        <supervise-dialog ref="superRef" @getList=getList></supervise-dialog>
        <register ref="regRef" @getList=getList />
        <review-dialog ref="reviewRef" @getList=getList></review-dialog>
        <el-dialog v-model="appDialog" title="审批用户" width="30%" center align-center>
          <el-radio-group v-model="appoveForm.state" style="width: 100%">
            <el-radio :label="2" size="large" border>通过</el-radio>
            <el-radio :label="3" size="large" border>驳回</el-radio>
          </el-radio-group>
          <template #footer>
            <span class="dialog-footer">
              <el-button @click="appDialog = false">取消</el-button>
              <el-button type="primary" @click="confirmApproval">确认</el-button>
            </span>
          </template>
        </el-dialog>
    </div>
</template>

<script setup>
import {getCurrentInstance, nextTick, onMounted, onUnmounted, reactive, ref, toRefs} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import superviseDialog from "../superviseUsers/components/superviseDialog.vue"
import { Register } from "@/layout/components";
import {delMonitor, getAgencyList, changeApprove, changeStatus} from "../../../../api/sysUsers"
import Cookies from "js-cookie";
import reviewDialog from "../../institution/components/viewInstitution.vue"

const { proxy } = getCurrentInstance();
const loading = ref(false);
const superRef = ref();
const regRef = ref(null)
const reviewRef = ref();
const data = reactive({
    queryParams: {
        pageNum: 1,
        pageSize: 10,
    },
    total: 0,
    dataList: [],
    isSuper: false,
    appDialog: false,
    appoveForm: {
      id: null,
      state: null
    }
});

const { queryParams, total, dataList, isSuper, appDialog, appoveForm } = toRefs(data);

onMounted(()=>{

  const userInfo = JSON.parse(Cookies.get('userInfo'))
  if(userInfo.identity == 0){data.isSuper = true}
    nextTick(() => {
        getList()
    })
})

onUnmounted(()=>{

})

const getList = async () => {
    loading.value = true
    const res = await getAgencyList(data.queryParams)
    if(res.code == 200){
      data.dataList = res.data.list
      data.total = res.data.total
    }else{
      ElMessage.warning(res.message)
    }
    loading.value = false
}

const openPwd = (type, value) => {
  superRef.value.openDialog(type, value);
}

const openDialog = (type, value)=>{
    if(type === 'view') {
        reviewRef.value.openDialog(value,type)
    }else {
        regRef.value.openDialog(type, value);
    }
}

const openApprove =(val)=>{
  data.appoveForm = {
    id: null,
    state: null
  }
  data.appoveForm.id = val.id
  data.appDialog = true
}

const confirmApproval = async () =>{
  if(data.appoveForm.state !== null){
    const res = await changeApprove(data.appoveForm)
    if(res.code == 200){
      ElMessage.success('审批成功')
      await getList()
      data.appDialog = false
    }else{
      ElMessage.warning(res.message)
    }
  }
}

const switchStatus = (e,val) => {
  ElMessageBox.confirm(
      '确定修改该机构当前状态？',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
      .then( async() => {
        const res = await changeStatus({id: val.id,status: e})
        if(res.code == 200){
          ElMessage.success('状态修改成功')
          await getList()
        }else{
          ElMessage.warning(res.message)
        }
      })
      .catch(() => {
        getList()
      })

}

/** 重置新增的表单以及其他数据  */
function reset() {
    proxy.resetForm("roleRef");
}
const handleDelete = (val) => {
    ElMessageBox.confirm(
        '确定删除此条数据？',
        '提示',
        {
            confirmButtonText: '确定',
            cancelButtonText: '取消',
            type: 'warning',
        })
        .then( async() => {
            const res = await delMonitor(val.id)
            if(res.code == 200){
              ElMessage.success('数据删除成功')
              getList()
            }else{
              ElMessage.warning(res.message)
            }
        })
}

</script>
